@@ -224,7 +224,7 @@ class MSAApp(FastAPI):
 
         return decorator
 
-    def logger_info(self, message: str, service_name: str, topic_name: str = "") -> None:
+    def logger_info(self, message: str, service_name: str = "", topic_name: str = "") -> None:
         """
         Sends message to pubsub topic.
 
@@ -233,12 +233,13 @@ class MSAApp(FastAPI):
             topic_name: name of pubsub topic that needs this message.
             service_name: the name of the service from which the call was made
         """
+        data = f"[{service_name}]: " + message if service_name else message
         if topic_name:
             with DaprClient() as client:
                 client.publish_event(
                     pubsub_name=PUBSUB_NAME,
                     topic_name=topic_name,
-                    data=f"[{service_name}]: "+ message,
+                    data=data,
                     data_content_type="application/json",
                 )
         self.logger.info(message)
@@ -862,7 +863,7 @@ class MSAApp(FastAPI):
             with open("config.json") as json_file:
                 config = MSAServiceDefinition.parse_obj(json.load(json_file))
                 data = ConfigDTO(config=config, one_time=False)
-            self.logger_info(data.json(), REGISTRY_TOPIC)
+            self.logger_info(data.json(), topic_name=REGISTRY_TOPIC)
             self.logger.info(f"Sent config to pubsub, {data}")
         except Exception as ex:
             self.logger.error(f"An error occurred while trying to send config to spkRegistry. Exception: {ex}")
