@@ -8,7 +8,7 @@ import re
 import socket
 import uuid
 from subprocess import getoutput
-from typing import Dict, List
+from typing import Dict, List, Tuple
 
 import GPUtil
 import psutil
@@ -35,20 +35,22 @@ from msaBase.models.sysinfo import (
 
 
 def get_hostname() -> str:
-    """Get socket.gethostname()
+    """
+    Get current host name.
 
     Returns:
-        hostname: str
+        hostname string
     """
     hostname: str = socket.gethostname()
     return hostname
 
 
 def get_list_partitions() -> List:
-    """Get psutil.disk_partitions()
+    """
+    Get mounted partitions as a list.
 
     Returns:
-        partitions_list: List = []
+        List of mounted partitions.
     """
     partitions_list = []
     partitions = psutil.disk_partitions()
@@ -58,10 +60,11 @@ def get_list_partitions() -> List:
 
 
 def get_gpus() -> List[MSAGPUInfo]:
-    """Get GPUtil.getGPUs()
+    """
+    Get GPU information.
 
     Returns:
-        list_gpus: List[MSAGPUInfo] = []
+        List of GPUs
     """
     gpus = GPUtil.getGPUs()
     list_gpus: List[MSAGPUInfo] = []
@@ -87,10 +90,11 @@ def get_gpus() -> List[MSAGPUInfo]:
 
 
 def get_partition_usage(partitions) -> Dict:
-    """Get psutil.disk_usage(partition)
+    """
+    Get disc usage statistics for given partitions.
 
     Returns:
-        ret: Dict = {"partition": list, "total": list, "used": list, "free": list, "percent": list}
+        Dictionary containing partition usage statistics info
     """
     lstotal = []
     lsused = []
@@ -118,10 +122,11 @@ def get_partition_usage(partitions) -> Dict:
 
 
 def get_map_disk_usage() -> Dict:
-    """Get get_partition_usage(get_list_partitions())
+    """
+    Get reformatted disk usage info
 
     Returns:
-        rdict: Dict
+        Dictionary containing reformatted disk usage statistics info
     """
     MapUsage: Dict = get_partition_usage(get_list_partitions())
     disk = MapUsage["partition"]
@@ -134,10 +139,11 @@ def get_map_disk_usage() -> Dict:
 
 
 def get_memory_usage() -> MSAMemoryUsage:
-    """Get psutil.virtual_memory()
+    """
+    Get virtual memory usage
 
     Returns:
-        mu: MSAMemoryUsage
+        Pydantic model containing memory usage information
     """
     mu: MSAMemoryUsage = MSAMemoryUsage()
     memory = psutil.virtual_memory()
@@ -155,10 +161,11 @@ def get_memory_usage() -> MSAMemoryUsage:
 
 
 def get_cpu_freq() -> MSACPUFrequency:
-    """Get psutil.cpu_freq()
+    """
+    Get CPU frequency information
 
     Returns:
-        cpf: MSACPUFrequency
+        Pydantic model containing CPU frequency information
     """
     cpf: MSACPUFrequency = MSACPUFrequency()
     cpf.current, cpf.min, cpf.max = psutil.cpu_freq()
@@ -166,10 +173,11 @@ def get_cpu_freq() -> MSACPUFrequency:
 
 
 def get_cpu_times() -> MSACPUTimes:
-    """Get psutil.cpu_times()
+    """
+    Get CPU timings information
 
     Returns:
-        cti: MSACPUTimes
+        Pydantic model containing CPU timings information
     """
     cti: MSACPUTimes = MSACPUTimes()
     (
@@ -188,10 +196,11 @@ def get_cpu_times() -> MSACPUTimes:
 
 
 def get_cpu_stats() -> MSACPUStats:
-    """Get psutil.cpu_times()
+    """
+    Get CPU statistics
 
     Returns:
-        cst: MSACPUStats
+        Pydantic model containing CPU statistics
     """
     cst: MSACPUStats = MSACPUStats()
     (
@@ -204,10 +213,11 @@ def get_cpu_stats() -> MSACPUStats:
 
 
 def get_disk_io() -> MSADiskIO:
-    """Get psutil.disk_io_counters()
+    """
+    Get disk input/output information.
 
     Returns:
-        dio: MSADiskIO
+        Pydantic model containing disk input/output information
     """
     dio: MSADiskIO = MSADiskIO()
     (
@@ -225,10 +235,11 @@ def get_disk_io() -> MSADiskIO:
 
 
 def get_network_io() -> MSANetworkIO:
-    """Get psutil.net_io_counters()
+    """
+    Get network input/output information.
 
     Returns:
-        nio: MSANetworkIO
+        Pydantic model containing network input/output information
     """
     nio: MSANetworkIO = MSANetworkIO()
     (
@@ -245,10 +256,11 @@ def get_network_io() -> MSANetworkIO:
 
 
 def get_network_adapters() -> List[MSANetworkAdapters]:
-    """Get psutil.net_if_addrs()
+    """
+    Get the addresses associated to each NIC (network interface card)
 
     Returns:
-        ret: List[MSANetworkAdapters] = []
+        List of Network Adapters List models
     """
     ret: List[MSANetworkAdapters] = []
     la: Dict = psutil.net_if_addrs()
@@ -269,10 +281,11 @@ def get_network_adapters() -> List[MSANetworkAdapters]:
 
 
 def get_temperatures() -> List[MSATemperatures]:
-    """Get psutil.sensors_temperatures()
+    """
+    Get hardware temperatures.
 
     Returns:
-        ret: List[MSATemperatures] = []
+        List of models containing temperature information.
     """
     ret: List[MSATemperatures] = []
     ta: Dict = psutil.sensors_temperatures()
@@ -291,10 +304,11 @@ def get_temperatures() -> List[MSATemperatures]:
 
 
 def get_network_stats() -> List[MSANetworkStats]:
-    """Get psutil.net_if_stats()
+    """
+    Get information about each NIC (network interface card)
 
     Returns:
-        ret: List[MSANetworkStats] = []
+        List of models containing network statistics information.
     """
     ret: List[MSANetworkStats] = []
     net_stats: Dict = psutil.net_if_stats()
@@ -312,10 +326,11 @@ def get_network_stats() -> List[MSANetworkStats]:
 
 
 def get_network_connections() -> List[MSANetworkConnection]:
-    """Get psutil.net_connections()
+    """
+    Get system-wide socket connections as a list
 
     Returns:
-        rlist: List[MSANetworkConnection] = []
+        List of models containing network connections information.
     """
     rlist: List[MSANetworkConnection] = []
     inlist = psutil.net_connections()
@@ -336,10 +351,11 @@ def get_network_connections() -> List[MSANetworkConnection]:
 
 
 def get_swap() -> MSASwap:
-    """Get psutil.swap_memory()
+    """
+    Get system swap memory statistics.
 
     Returns:
-        sw: MSASwap
+        Pydantic model containing system swap memory information
     """
     swap = psutil.swap_memory()
     sw: MSASwap = MSASwap()
@@ -351,7 +367,8 @@ def get_swap() -> MSASwap:
 
 
 def get_load_average() -> List[float]:
-    """Returns the CPU load average in tuple[1min, 5min, 15min].
+    """
+    Returns the CPU load average in tuple[1min, 5min, 15min].
 
     Returns:
         1min: total usage
@@ -362,10 +379,11 @@ def get_load_average() -> List[float]:
     return [x / psutil.cpu_count() * 100 for x in psutil.getloadavg()]
 
 
-def get_cpu_usage(user: str = None, ignore_self: bool = False) -> tuple[int, int, str]:
-    """Returns the total CPU usage for all available cores.
+def get_cpu_usage(user: str = None, ignore_self: bool = False) -> Tuple[int, int, str]:
+    """
+    Returns the total CPU usage for all available cores.
 
-    Args:
+    Parameters:
         user: If given, returns only the total CPU usage of all processes for the given user.
         ignore_self: If ``True`` the process that runs this script will be ignored.
 
@@ -373,7 +391,6 @@ def get_cpu_usage(user: str = None, ignore_self: bool = False) -> tuple[int, int
         total: total usage
         largest_process: largest process usage
         largest_process_name: name of the largest process
-
     """
     pid = os.getpid()
     cmd = "ps aux"
@@ -395,10 +412,11 @@ def get_cpu_usage(user: str = None, ignore_self: bool = False) -> tuple[int, int
 
 
 def get_sysinfo() -> MSASystemInfo:
-    """Get MSASystemInfo
-    Returns:
-        system_info: Pydantic System Info Model.
+    """
+    Get system information.
 
+    Returns:
+        Pydantic System Info Model.
     """
     system_info: MSASystemInfo = MSASystemInfo()
     try:
@@ -449,9 +467,11 @@ def get_sysinfo() -> MSASystemInfo:
 
 
 def get_sysgpuinfo() -> MSASystemGPUInfo:
-    """Get MSASystemGPUInfo
+    """
+    Get GPU information
+
     Returns:
-        system_gpu_info: Pydantic System GPU Info Model.
+        Pydantic model containing GPU information
     """
     system_gpu_info: MSASystemGPUInfo = MSASystemGPUInfo()
     try:
